Learn R Programming

JFM (version 1.0.1)

build_3d_mesh: build_3d_mesh

Description

This function reads a XYZRGB text file, requires a search radius in meters and an output file name to save the resulting mesh. for data format see file in package extdata folder

Usage

build_3d_mesh(path2myXYZRGBtxt, search_radius, file_name)

Value

A 3D triangular mesh

Arguments

path2myXYZRGBtxt

Path to the XYZRGB.txt input file

search_radius

Path to the XYZRGB.txt input file

file_name

name of the output .ply mesh file

Examples

Run this code
if (FALSE) path2myXYZRGBtxt<-system.file("extdata", "test.txt", package = "JFM")

file_name<- "test"

mesh3d<-build_3d_mesh(path2myXYZRGBtxt,0.5,file_name)

Run the code above in your browser using DataLab