powered by
This function calculates joint orientation with the least square method selecting vertexes of each facet plane
calculate_joints(vertici_tr, indici_tri, normal_from_wild)
a matrix of least square plane for each joint
list of facets vertexes coordinates ("vb property of mesh3d object")
list of facets indexes ("it property of mesh3d object")
matrix of data resulting from wildfire search
if (FALSE) { mesh3d<-build_3d_mesh(path2myXYZRGBtxt,0.5,file_name) normali_recalc<-Rcpp_wildfire_search(7,normals[,1:3],neighbours) joint_list_Cpp<-calculate_joints(mesh3d,normali_recalc)}
Run the code above in your browser using DataLab