Learn R Programming

JFM (version 1.0.1)

compute_plane_area_rcpp: returns the sum of the area of facets belonging to the same plane

Description

returns the sum of the area of facets belonging to the same plane

Value

the sum of the area of facets belonging to the same plane given tr_area and id_fam_no_zero

Arguments

tr_area

a matrix with the first column facet area and second column the ID of plane it belows

id_fam_no_zero

the list of planes ID