Learn R Programming

JFM (version 1.0.1)

findNeighbourFacets: findNeighbourFacets

Description

This function finds the IDs of each mesh facet It requires number of cores of your pc to use and list of facets indexes corresponding to the "it" property of mesh3d object.

Usage

findNeighbourFacets(no_cores, indici_tri)

Value

a matrix of indexes of facets neighbours of target face saved on working dir

Arguments

no_cores

number of core to use in search computation

indici_tri

list of facets indexes ("it property of mesh3d object")

Examples

Run this code

if (FALSE) indici_tri<-t(mesh3d[['it']])
 
require("parallel")

detectCores()

no_cores <- detectCores() - 4 ### keep free some cores

neighbours<-findNeighbourFacets(no_cores,indici_tri)

Run the code above in your browser using DataLab