Learn R Programming

JFM (version 1.0.1)

find_neighbours_rcpp: This function finds the rows IDs of neighbours of each mesh facet. It requires a list of facets indexes corresponding to the "it" property of mesh3d object

Description

This function finds the rows IDs of neighbours of each mesh facet. It requires a list of facets indexes corresponding to the "it" property of mesh3d object

Usage

find_neighbours_rcpp(indici_tr)

Value

this function returns the rows IDs of neighbours of each mesh facet given a list of facets indexes indici_tri

Arguments

indici_tr

matrix of facets ID the "it" property of a mesh3D

Examples

Run this code
indici_tri<-matrix(data = c(1, 2, 3 ,5, 6,
3, 2, 3, 5,7, 8 ,1),
nrow = 4,ncol = 3, byrow = TRUE)  
find_neighbours_rcpp(indici_tri)

Run the code above in your browser using DataLab