Learn R Programming

JFM (version 1.0.1)

least_square_plane_rcpp: returns the coefficients of the least square plane and the relative mean square error

Description

returns the coefficients of the least square plane and the relative mean square error

Usage

least_square_plane_rcpp(PointsXYZ)

Value

returns the coefficients of the least square plane and the relative mean square error of a set of 3d points PointsXYZ

Arguments

PointsXYZ

matrix of coordinates of point

Examples

Run this code
list_xyz<-matrix(data = c(-10.0, -10.0, -15.0 ,10.0, -10.0,
-5.0, -10.0, 10.0, 5.0, 10.0, 10.0 ,15.0),
nrow = 4,ncol = 3, byrow = TRUE)
least_square_plane_rcpp(list_xyz)

Run the code above in your browser using DataLab