find_neighbours_rcpp: This function finds the rows IDs of neighbours of each mesh facet. It requires a list of facets indexes corresponding to the "it" property of mesh3d object
Description
This function finds the rows IDs of neighbours of each mesh facet. It requires a list of facets indexes corresponding to the "it" property of mesh3d object
Usage
find_neighbours_rcpp(indici_tr)
Value
this function returns the rows IDs of neighbours of each mesh facet given a list of facets indexes indici_tri